======================================================================
Domain Entities, Root Aggregate, Events and EventBus with Async flavor
======================================================================

.. image:: https://img.shields.io/pypi/v/domain_eventbus.svg
        :target: https://pypi.python.org/pypi/domain-eventbus

.. image:: https://img.shields.io/travis/adyshev/eventbus.svg
        :target: https://travis-ci.com/adyshev/eventbus

.. image:: https://readthedocs.org/projects/eventbus/badge/?version=latest
        :target: https://eventbus.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/adyshev/eventbus/shield.svg
     :target: https://pyup.io/repos/github/adyshev/eventbus/
     :alt: Updates

|

Domain Entity, Root Aggregate, Bus and Events from the awesome johnbywater/eventsourcing library with
async support added.

.. _Github repo: https://github.com/johnbywater/eventsourcing

* Free software: MIT license
* Documentation: https://eventbus.readthedocs.io.

Features
--------

* async support
* storage agnostic
